==> humhub-1.8.0-beta.1.tar.gz: humhub-1.8.0-beta.1/protected/humhub/modules/user/messages/de/profile.php <==
<?php
return array (
  '%y Years' => '%y Jahre',
  '<b>This profile stream is still empty!</b>' => '<b>Dieser Profilstream ist noch leer!</b>',
  '<b>This profile stream is still empty</b><br>Be the first and post something...' => '<b>Dieser Profil-Stream ist noch leer</b><br />Sei der erste und schreibe etwas ...',
  '<b>Your profile stream is still empty</b><br>Get started and post something...' => '<strong>Dein Stream ist noch leer!</strong><br />Mache den Anfang und schreibe etwas ...',
  '<strong>About</strong> this user' => '<strong>Über</strong> diesen Nutzer',
  '<strong>Profile</strong> menu' => '<strong>Profil</strong>-Menü',
  'About' => 'Über mich',
  'Allow other selection' => 'Weitere Auswahl zulassen',
  'Birthday' => 'Geburtstag',
  'Birthday field options' => 'Geburtstagsfeld-Optionen',
  'Checkbox' => 'Kontrollkästchen',
  'Checkbox List' => 'Kontrollkästchen-Liste',
  'Checkbox field options' => 'Kontrollkästchenfeld-Optionen',
  'City' => 'Ort',
  'Comma separated country codes, e.g. DE,EN,AU' => 'Komma getrennte Ländercodes, z. B. DE,EN,AU',
  'Communication' => 'Kommunikation',
  'Country' => 'Land',
  'Created at' => 'Erstellt am',
  'Created by' => 'Erstellt durch',
  'Creation date of the user' => 'Erstellungsdatum des Benutzers',
  'Custom' => 'Divers',
  'Date' => 'Datum',
  'Date(-time) field options' => 'Datums(-Uhrzeit)feld-Optionen',
  'Datetime' => 'Datum/Uhrzeit',
  'Default value' => 'Standardwert',
  'Description' => 'Beschreibung',
  'E-Mail' => 'E-Mail',
  'E-mail address of the user' => 'E-Mail Adresse des Benutzers',
  'Edit account' => 'Benutzerkonto bearbeiten',
  'Editable' => 'Editierbar',
  'Facebook URL' => 'Facebook-URL',
  'Fax' => 'Fax',
  'Female' => 'Weiblich',
  'Field Type could not be changed!' => 'Feldtyp konnte nicht geändert werden!',
  'Fieldtype' => 'Feldtyp',
  'First name' => 'Vorname',
  'Flickr URL' => 'Flickr-URL',
  'Followers' => 'Follower',
  'Following' => 'Folgend',
  'Friends' => 'Freunde',
  'Gender' => 'Geschlecht',
  'General' => 'Allgemein',
  'Hide age per default' => 'Standardmäßig Alter verstecken',
  'Hide year in profile' => 'Jahr im Profil verbergen',
  'ID' => 'ID',
  'Internal Name' => 'Interner Name',
  'Internal name already in use!' => 'Der interne Name wird bereits verwendet!',
  'Internal name could not be changed!' => 'Der interne Name konnte nicht geändert werden!',
  'Invalid field type!' => 'Ungültiger Feldtyp!',
  'Invalid!' => 'Ungültig!',
  'LDAP Attribute' => 'LDAP-Attribut',
  'Last login date of the user' => 'Letzter Login des Benutzers',
  'Last name' => 'Nachname',
  'LinkedIn URL' => 'LinkedIn-URL',
  'MSN' => 'MSN',
  'Male' => 'Männlich',
  'Markdown' => 'Markdown',
  'Maximum length' => 'Maximallänge',
  'Maximum value' => 'Maximum',
  'Minimum length' => 'Minimallänge',
  'Minimum value' => 'Minimum',
  'Mobile' => 'Mobil',
  'Module' => 'Modul',
  'Must contain at least one character.' => 'Muss mindestens ein Zeichen enthalten.',
  'MySpace URL' => 'MySpace-URL',
  'Number' => 'Zahl',
  'Number field options' => 'Zahlenfeld-Optionen',
  'One option per line. Key=>Value Format (e.g. yes=>Yes)' => 'Eine Option pro Zeile. Schlüssel=&gt;Wert-Format (z.B. yes=&gt;Ja)',
  'Only alphanumeric characters allowed!' => 'Nur alphanumerische Zeichen erlaubt!',
  'Other:' => 'Weiteres:',
  'Phone Private' => 'Telefon privat',
  'Phone Work' => 'Telefon dienstlich',
  'Please select:' => 'Bitte wähle:',
  'Possible values' => 'Mögliche Werte',
  'Profile Field Category' => 'Profilfeld-Kategorie',
  'Regular Expression: Error message' => 'Regulärer Ausdruck: Fehlermeldung',
  'Regular Expression: Validator' => 'Regulärer Ausdruck: Validator',
  'Required' => 'Erforderlich',
  'Searchable' => 'Durchsuchbar',
  'Select List' => 'Auswahlliste',
  'Select field options' => 'Auswahlfeld-Optionen',
  'Show at registration' => 'Bei der Registrierung anzeigen',
  'Show date/time picker' => 'Zeige Datums/Zeit Picker',
  'Skype Nickname' => 'Skype-Name',
  'Social bookmarks' => 'Links',
  'Sort order' => 'Sortierung',
  'Spaces' => 'Spaces',
  'State' => 'Bundesland/Kanton',
  'Stream' => 'Stream',
  'Street' => 'Straße',
  'Supported ISO3166 country codes' => 'Unterstützte ISO3166 Länder Codes',
  'Text' => 'Text',
  'Text Area' => 'Textbereich',
  'Text Field Options' => 'Textfeld-Optionen',
  'Text area field options' => 'Textbereichsfeld-Optionen',
  'This profile is no longer available!' => 'Dieses Profil ist nicht mehr verfügbar!',
  'This user account is not approved yet!' => 'Dieser Account wurde noch nicht freigeschaltet!',
  'This will add an additional input element for custom values' => 'Fügt ein weiteres Eingabeelement für individuelle Werte hinzu',
  'Title' => 'Titel',
  'Translation Category ID' => 'Übersetzungs-Kategorie-ID',
  'Twitter URL' => 'Twitter-URL',
  'Type Config' => 'Typ-Konfiguration',
  'Updated at' => 'Aktualisiert am',
  'Updated by' => 'Aktualisiert durch',
  'Url' => 'URL',
  'Username' => 'Benutzername',
  'Validator' => 'Validator',
  'Vimeo URL' => 'Vimeo-URL',
  'Visible' => 'Sichtbar',
  'XMPP Jabber Address' => 'XMPP Jabber-Addresse',
  'Xing URL' => 'XING-URL',
  'You need to login to view this user profile!' => 'Sie müssen sich anmelden, um das Profil zu sehen!',
  'YouTube URL' => 'YouTube-URL',
  'Zip' => 'PLZ',
);

==> humhub-1.17.0-beta.1.tar.gz: humhub-1.17.0-beta.1/protected/humhub/modules/user/messages/de/profile.php <==
<?php
return [
  '%y Years' => '%y Jahre',
  '<b>This profile stream is still empty!</b>' => '<b>Dieser Profilstream ist noch leer!</b>',
  '<b>This profile stream is still empty</b><br>Be the first and post something...' => '<b>Dieser Profil-Stream ist noch leer</b><br />Sei der erste und schreibe etwas ...',
  '<b>Your profile stream is still empty</b><br>Get started and post something...' => '<strong>Dein Stream ist noch leer!</strong><br />Mache den Anfang und schreibe etwas ...',
  '<strong>About</strong> this user' => '<strong>Über</strong> diesen Nutzer',
  '<strong>Profile</strong> menu' => '<strong>Profil</strong>-Menü',
  'About' => 'Über mich',
  'Allow other selection' => 'Weitere Auswahl zulassen',
  'Birthday' => 'Geburtstag',
  'Birthday field options' => 'Geburtstagsfeld-Optionen',
  'Checkbox' => 'Kontrollkästchen',
  'Checkbox List' => 'Kontrollkästchen-Liste',
  'Checkbox field options' => 'Kontrollkästchenfeld-Optionen',
  'City' => 'Ort',
  'Comma separated country codes, e.g. DE,EN,AU' => 'Komma getrennte Ländercodes, z. B. DE,EN,AU',
  'Communication' => 'Kommunikation',
  'Country' => 'Land',
  'Created at' => 'Erstellt am',
  'Created by' => 'Erstellt durch',
  'Creation date of the user' => 'Erstellungsdatum des Benutzers',
  'Date' => 'Datum',
  'Date(-time) field options' => 'Datums(-Uhrzeit)feld-Optionen',
  'Datetime' => 'Datum/Uhrzeit',
  'Default value' => 'Standardwert',
  'Description' => 'Beschreibung',
  'Diverse' => 'Divers',
  'E-Mail' => 'E-Mail',
  'E-mail address of the user' => 'E-Mail Adresse des Benutzers',
  'Each line must be formatted as Key=>Value!' => 'Jede Zeile muss als Schlüssel=&gt;Wert formatiert sein!',
  'Edit account' => 'Benutzerkonto bearbeiten',
  'Editable' => 'Editierbar',
  'Facebook URL' => 'Facebook-URL',
  'Fax' => 'Fax',
  'Female' => 'Weiblich',
  'Field Type could not be changed!' => 'Feldtyp konnte nicht geändert werden!',
  'Fieldtype' => 'Feldtyp',
  'First name' => 'Vorname',
  'Followers' => 'Follower',
  'Following' => 'Folgend',
  'Friends' => 'Freunde',
  'Gender' => 'Geschlecht',
  'General' => 'Allgemein',
  'Hide age per default' => 'Standardmäßig Alter verstecken',
  'Hide year in profile' => 'Jahr im Profil verbergen',
  'ID' => 'ID',
  'Instagram URL' => 'Instagram URL',
  'Internal Name' => 'Interner Name',
  'Internal name already in use!' => 'Der interne Name wird bereits verwendet!',
  'Internal name could not be changed!' => 'Der interne Name konnte nicht geändert werden!',
  'Invalid field type!' => 'Ungültiger Feldtyp!',
  'Invalid!' => 'Ungültig!',
  'LDAP Attribute' => 'LDAP-Attribut',
  'Last login date of the user' => 'Letzter Login des Benutzers',
  'Last name' => 'Nachname',
  'Link Prefix (e.g. https://, mailto:, tel://)' => 'Link Prefix (z.B. https://, mailto:, tel://)',
  'LinkedIn URL' => 'LinkedIn-URL',
  'Male' => 'Männlich',
  'Markdown' => 'Markdown',
  'Mastodon URL' => 'Mastodon URL',
  'Maximum length' => 'Maximallänge',
  'Maximum value' => 'Maximum',
  'Minimum length' => 'Minimallänge',
  'Minimum value' => 'Minimum',
  'Mobile' => 'Mobil',
  'Module' => 'Modul',
  'Must contain at least one character.' => 'Muss mindestens ein Zeichen enthalten.',
  'Number' => 'Zahl',
  'Number field options' => 'Zahlenfeld-Optionen',
  'One option per line. Key=>Value Format (e.g. yes=>Yes)' => 'Eine Option pro Zeile. Schlüssel=&gt;Wert-Format (z.B. yes=&gt;Ja)',
  'Only alphanumeric characters allowed!' => 'Nur alphanumerische Zeichen erlaubt!',
  'Other:' => 'Weiteres:',
  'Phone Private' => 'Telefon privat',
  'Phone Work' => 'Telefon dienstlich',
  'Please select:' => 'Bitte wähle:',
  'Possible values' => 'Mögliche Werte',
  'Profile Field Category' => 'Profilfeld-Kategorie',
  'Regular Expression: Error message' => 'Regulärer Ausdruck: Fehlermeldung',
  'Regular Expression: Validator' => 'Regulärer Ausdruck: Validator',
  'Required' => 'Erforderlich',
  'Searchable' => 'Durchsuchbar',
  'Select List' => 'Auswahlliste',
  'Select field options' => 'Auswahlfeld-Optionen',
  'Show at registration' => 'Bei der Registrierung anzeigen',
  'Show date/time picker' => 'Zeige Datums/Zeit Picker',
  'Social bookmarks' => 'Links',
  'Sort order' => 'Sortierung',
  'Spaces' => 'Spaces',
  'State' => 'Bundesland/Kanton',
  'Stream' => 'Stream',
  'Street' => 'Straße',
  'Supported ISO3166 country codes' => 'Unterstützte ISO3166 Länder Codes',
  'Text' => 'Text',
  'Text Area' => 'Textbereich',
  'Text Field Options' => 'Textfeld-Optionen',
  'Text area field options' => 'Textbereichsfeld-Optionen',
  'This profile is disabled!' => 'Dieses Profil ist deaktiviert!',
  'This profile is no longer available!' => 'Dieses Profil ist nicht mehr verfügbar!',
  'This user account is not approved yet!' => 'Dieser Account wurde noch nicht freigeschaltet!',
  'This will add an additional input element for custom values' => 'Fügt ein weiteres Eingabeelement für individuelle Werte hinzu',
  'TikTok URL' => 'TikTok URL',
  'Title' => 'Titel',
  'Translation Category ID' => 'Übersetzungs-Kategorie-ID',
  'Twitter URL' => 'Twitter-URL',
  'Type Config' => 'Typ-Konfiguration',
  'Updated at' => 'Aktualisiert am',
  'Updated by' => 'Aktualisiert durch',
  'Use as Directory filter' => 'Als Filter im Verzeichnis verwenden',
  'Username' => 'Benutzername',
  'Validator' => 'Validator',
  'Vimeo URL' => 'Vimeo-URL',
  'Visible' => 'Sichtbar',
  'Website URL' => 'URL',
  'XMPP Jabber Address' => 'XMPP Jabber-Addresse',
  'Xing URL' => 'XING-URL',
  'You need to login to view this user profile!' => 'Um dieses Profil sehen zu können musst du einloggt sein!',
  'YouTube URL' => 'YouTube-URL',
  'Zip' => 'PLZ',
  '{attribute} is required!' => '{attribute} ist erforderlich!',
];
